OC.L10N.register(
    "files_sharing",
    {
    "File shares" : "Tiedostojaot",
    "Downloaded via public link" : "Ladattu julkista linkkiä käyttäen",
    "Downloaded by {email}" : "Ladannut {email}",
    "{file} downloaded via public link" : "{file} ladattu julkisen linkin kautta",
    "{email} downloaded {file}" : "{email} latasi tiedoston {file}",
    "Shared with group {group}" : "Jaettu ryhmälle {group}",
    "Removed share for group {group}" : "Lopetettu jakaminen ryhmälle {group}",
    "{actor} shared with group {group}" : "{actor} jakoi ryhmälle {group}",
    "{actor} removed share for group {group}" : "{actor} lopetti jakamisen ryhmälle {group}",
    "Share for group {group} expired" : "Jako ryhmälle {group} vanhentui",
    "You shared {file} with group {group}" : "Jaoit kohteen {file} ryhmälle {group}",
    "You removed group {group} from {file}" : "Poistit ryhmän {group} tiedostosta {file}",
    "{actor} shared {file} with group {group}" : "{actor} jakoi kohteen {file} ryhmälle {group}",
    "{actor} removed group {group} from {file}" : "{actor} poisti ryhmän {group} kohteen {file} käyttöoikeudet",
    "Share for file {file} with group {group} expired" : "Tiedoston {file} jako ryhmän {group} kanssa on päättynyt",
    "Shared as public link" : "Jaettu julkisella linkillä",
    "Removed public link" : "Julkinen linkki poistettu",
    "Public link expired" : "Julkinen linkki vanhentui",
    "{actor} shared as public link" : "{actor} jakoi julkisena linkkinä",
    "{actor} removed public link" : "{actor} poisti julkisen linkin",
    "Public link of {actor} expired" : "Käyttäjän {actor} julkinen linkki vanheni",
    "You shared {file} as public link" : "Jaoit kohteen {file} julkisena linkkinä",
    "You removed public link for {file}" : "Poistit kohteen {file} julkisen linkin",
    "Public link expired for {file}" : "Kohteen {file} julkinen linkki vanheni",
    "{actor} shared {file} as public link" : "{actor} jakoi kohteen {file} julkisena linkkinä",
    "{actor} removed public link for {file}" : "{actor} poisti kohteen {file} julkisen linkin",
    "Public link of {actor} for {file} expired" : "Käyttäjän {actor} julkinen linkki kohteeseen {file} vanhentui",
    "{user} accepted the remote share" : "{user} hyväksyi etäjaon",
    "{user} declined the remote share" : "{user} kieltäytyi etäjaosta",
    "You received a new remote share {file} from {user}" : "Vastaanotit uuden etäjaon {file} käyttäjältä {user}",
    "{user} accepted the remote share of {file}" : "{user} hyväksyi etäjaon {file}",
    "{user} declined the remote share of {file}" : "{user} kieltäytyi etäjaosta {file}",
    "{user} unshared {file} from you" : "{user} lopetti kohteen {file} jakamisen kanssasi",
    "Shared with {user}" : "Jaettu käyttäjälle {user}",
    "Removed share for {user}" : "Poisti jaon käyttäjälle {user}",
    "You removed yourself" : "Poistit itsesi",
    "{actor} removed themselves" : "{actor} poisti itsensä",
    "{actor} shared with {user}" : "{actor} jakoi käyttäjälle {user}",
    "{actor} removed share for {user}" : "{actor} poisti jaon käyttäjälle {user}",
    "Shared by {actor}" : "Jakanut {actor}",
    "{actor} removed share" : "{actor} lopetti jakamisen",
    "Share for {user} expired" : "Jako käyttäjälle {user} vanhentui",
    "Share expired" : "Jako vanhentui",
    "You shared {file} with {user}" : "Jaoit kohteen {file} käyttäjälle {user}",
    "You removed {user} from {file}" : "Poistit käyttäjän {user} kohteen {file} käyttöoikeudet",
    "You removed yourself from {file}" : "Poistit itsesi tiedostosta {file}",
    "{actor} removed themselves from {file}" : "{actor} poisti itsensä tiedostosta {file}",
    "{actor} shared {file} with {user}" : "{actor} jakoi kohteen {file} käyttäjälle {user}",
    "{actor} removed {user} from {file}" : "{actor} poisti käyttäjän {user} kohteen {file} käyttöoikeudet",
    "{actor} shared {file} with you" : "{actor} jakoi kohteen {file} kanssasi",
    "{actor} removed you from the share named {file}" : "{actor} poisti sinut jaosta nimeltä {file}",
    "Share for file {file} with {user} expired" : "Tiedoston {file} jako käyttäjän {user} kanssa on päättynyt",
    "Share for file {file} expired" : "Tiedoston {file} jako vanhentui",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Tiedosto tai kansio, joka on jaettu sähköpostitse tai julkisen linkin kautta, on <strong>ladattu</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Tiedosto tai kansio on jaettu <strong>toiselta palvelimelta</strong>",
    "Sharing" : "Jakaminen",
    "A file or folder has been <strong>shared</strong>" : "Tiedosto tai kansio on <strong>jaettu</strong>",
    "Shared link" : "Jaettu linkki",
    "Wrong share ID, share does not exist" : "Väärä jaon ID, jakoa ei ole olemassa",
    "Could not delete share" : "Jaon poistaminen epäonnistui",
    "Please specify a file or folder path" : "Määritä tiedoston tai kansion polku",
    "Wrong path, file/folder does not exist" : "Väärä polku, tiedostoa/kansiota ei ole olemassa",
    "Could not create share" : "Jaon luominen epäonnistui",
    "Group sharing is disabled by the administrator" : "Ylläpitäjä on estänyt ryhmäjakamisen",
    "Please specify a valid group" : "Määritä kelvollinen ryhmä",
    "Public link sharing is disabled by the administrator" : "Ylläpitäjä on estänyt julkisen linkin jakamisen",
    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Kohteen %s jakaminen lähettämällä salasana Nextcloud Talkin kautta epäonnistui, koska Nextcloud Talk ei ole käytössä",
    "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Kohteen %1$s jakaminen epäonnistui, koska tietovarasto ei salli %2$s tyyppisiä jakoja",
    "Please specify a valid team" : "Määritä kelvollinen tiimi",
    "Sharing %s failed because the back end does not support room shares" : "Kohteen %s jakaminen epäonnistui, koska taustaosa ei tue huonejakoja",
    "Unknown share type" : "Tuntematon jaon tyyppi",
    "Not a directory" : "Ei hakemisto",
    "Could not lock node" : "Solmua ei voitu lukita",
    "Public upload is only possible for publicly shared folders" : "Julkinen lähettäminen on mahdollista vain julkisesti jaetuille kansioille",
    "Share must at least have READ or CREATE permissions" : "Jaolla tulee olla vähintään luku- tai kirjoitusoikeus",
    "Public upload disabled by the administrator" : "Ylläpitäjä on estänyt julkisen lähetyksen",
    "Could not lock path" : "Polun lukitseminen ei onnistunut",
    "Wrong or no update parameter given" : "Päivitettävä parametri puuttuu tai on väärin",
    "Wrong password" : "Väärä salasana",
    "shared by %s" : "käyttäjän %s jakama",
    "Download" : "Lataa",
    "Add to your %s" : "Lisää %siisi",
    "Direct link" : "Suora linkki",
    "Share API is disabled" : "Jakamisrajapinta on poistettu käytöstä",
    "File sharing" : "Tiedostonjako",
    "Share will expire tomorrow" : "Jako vanhenee huomenna",
    "Your share of {node} will expire tomorrow" : "Jakosi {node} vanhenee huomenna",
    "You received {share} as a share by {user}" : "Vastaanotit jaon {share} käyttäjältä {user}",
    "You received {share} to group {group} as a share by {user}" : "Vastaanotit jaon {share} ryhmään {group} käyttäjältä {user}",
    "Accept" : "Hyväksy",
    "Decline" : "Kieltäydy",
    "Open \"%s\"" : "Avaa \"%s\"",
    "People" : "Ihmiset",
    "The request will be password protected." : "Pyyntö suojataan salasanalla.",
    "When should the request expire?" : "Milloin pyynnön tulee vanhentua?",
    "Expiration date" : "Vanhenemispäivä",
    "Select a date" : "Valitse päivämäärä",
    "Set a password" : "Aseta salasana",
    "Password" : "Salasana",
    "Enter a valid password" : "Kirjoita oikea salasana",
    "Generate a new password" : "Luo uusi salasana",
    "Your administrator has enforced a password protection." : "Ylläpitäjä on pakottanut salasanasuojauksen.",
    "Link copied to clipboard" : "Linkki kopioitu leikepöydälle",
    "Email already added" : "Sähköpostiosoite on jo lisätty",
    "Invalid email address" : "Virheellinen sähköpostiosoite",
    "Share link" : "Jaa linkki",
    "Copy to clipboard" : "Kopioi leikepöydälle",
    "Send link via email" : "Lähetä linkki sähköpostitse",
    "Select a destination" : "Valitse sijainti",
    "Select" : "Valitse",
    "What are you requesting?" : "Mitä pyydät?",
    "Request subject" : "Pyynnön aihe",
    "Birthday party photos, History assignment…" : "Syntymäpäiväkuvia, historiantehtäviä…",
    "Where should these files go?" : "Mihin nämä tiedostot kuuluvat?",
    "Upload destination" : "Lähetyksen kohde",
    "The uploaded files are visible only to you unless you choose to share them." : "Lähetetyt tiedostot ovat vain sinulle näkyvissä, ellet päätä jakaa niitä.",
    "Add a note" : "Lisää muistiinpano",
    "Close" : "Sulje",
    "Error creating the share: {errorMessage}" : "Virhe luotaessa jakoa: {errorMessage}",
    "Error creating the share" : "Virhe jakoa luotaessa",
    "Cancel" : "Peruuta",
    "Continue" : "Jatka",
    "Accept shares from other accounts and groups by default" : "Hyväksy jaot muilta tileiltä ja ryhmiltä oletusarvoisesti",
    "Choose a default folder for accepted shares" : "Valitse oletuskansio hyväksytyille jaoille",
    "Invalid path selected" : "Virheellinen polku valittu",
    "Unknown error" : "Tuntematon virhe",
    "Set default folder for accepted shares" : "Aseta oletuskansio hyväksytyille jaoille",
    "Reset" : "Palauta",
    "Reset folder to system default" : "Palauta kansio järjestelmän oletukseksi",
    "Share expiration: " : "Jaon vanhentuminen:",
    "group" : "ryhmä",
    "conversation" : "keskustelu",
    "remote" : "etä",
    "remote group" : "etäryhmä",
    "guest" : "vieras",
    "Shared with the group {user} by {owner}" : "Jaettu ryhmän {user} kanssa käyttäjältä {owner}",
    "Shared with the conversation {user} by {owner}" : "Jaettu keskustelun {user} kanssa käyttäjältä {owner}",
    "Shared with {user} by {owner}" : "{owner} jakoi käyttäjälle {user}",
    "Open Sharing Details" : "Avaa jakamisen yksityiskohdat",
    "Added by {initiator}" : "Lisäyksen tehnyt {initiator}",
    "Via “{folder}”" : "“{folder}” kautta",
    "Unshare" : "Lopeta jakaminen",
    "Cannot copy, please copy the link manually" : "Kopioiminen ei onnistu. Kopioi linkki manuaalisesti",
    "Copy internal link to clipboard" : "Kopioi sisäinen linkki leikepöydälle",
    "Link copied" : "Linkki kopioitu",
    "Internal link" : "Sisäinen linkki",
    "Shared via link by {initiator}" : "Jaettu linkin kautta käyttäjältä {initiator}",
    "Mail share ({label})" : "Sähköpostijako ({label})",
    "Share link ({label})" : "Jaa linkki ({label})",
    "Share link ({index})" : "Jaa linkki ({index})",
    "Create public link" : "Luo julkinen linkki",
    "Actions for \"{title}\"" : "Toiminnot kohteelle \"{title}\"",
    "Copy public link of \"{title}\" to clipboard" : "Kopioi kohteen \"{title}\" julkinen linkki leikepöydälle",
    "Error, please enter proper password and/or expiration date" : "Virhe, lisää kelvollinen salasana ja/tai päättymispäivä",
    "Link share created" : "Linkkijako luotu",
    "Error while creating the share" : "Virhe jakoa luotaessa",
    "Please enter the following required information before creating the share" : "Anna seuraavat vaaditut tiedot, ennen kuin luot jaon",
    "Password protection (enforced)" : "Salasanasuojaus (pakotettu)",
    "Password protection" : "Salasanasuojaus",
    "Enter a password" : "Syötä salasana",
    "Create share" : "Luo jako",
    "Customize link" : "Mukauta linkkiä",
    "Generate QR code" : "Luo QR-koodi",
    "Add another link" : "Lisää toinen linkki",
    "Create a new share link" : "Luo uusi jakolinkki",
    "View only" : "Vain katselu",
    "Can edit" : "Voi muokata",
    "Custom permissions" : "Mukautetut oikeudet",
    "Resharing is not allowed" : "Uudelleenjako ei ole sallittu",
    "Name or email …" : "Nimi tai sähköposti...",
    "Name, email, or Federated Cloud ID …" : "Nimi, sähköposti tai federoitu Cloud ID...",
    "Searching …" : "Haetaan…",
    "No elements found." : "Elementtejä ei löytynyt.",
    "Search globally" : "Hae globaalisti",
    "Guest" : "Vieras",
    "Group" : "Ryhmä",
    "Email" : "Sähköposti",
    "Team" : "Tiimi",
    "Talk conversation" : "Talk-keskustelu",
    "Deck board" : "Deck-taulu",
    "on {server}" : "palvelimella {server}",
    "Note:" : "Huomioi:",
    "File drop" : "Tiedoston pudotus",
    "Upload files to {foldername}." : "Lähetä tiedostot kansioon {foldername}.",
    "By uploading files, you agree to the terms of service." : "Lähettämällä tiedostot hyväksyt käyttöehdot.",
    "View terms of service" : "Näytä käyttöehdot",
    "Terms of service" : "Käyttöehdot",
    "Upload files to {folder}" : "Lähetä tiedostot kansioon {folder}",
    "{ownerDisplayName} shared a folder with you." : "{ownerDisplayName} jakoi kansion kanssasi.",
    "Name" : "Nimi",
    "Enter your name" : "Kirjoita nimesi",
    "Share with {userName}" : "Jaa käyttäjän {userName} kanssa",
    "Share with group" : "Jaa ryhmän kanssa",
    "Share in conversation" : "Jaa keskustelussa",
    "Share with remote group" : "Jaa etäryhmän kanssa",
    "Share with guest" : "Jaa vieraan kanssa",
    "Update share" : "Päivitä jako",
    "Save share" : "Tallenna jako",
    "Read" : "Lue",
    "Create" : "Luo",
    "Edit" : "Muokkaa",
    "Share" : "Jaa",
    "Delete" : "Poista",
    "Password field cannot be empty" : "Salasanakenttä ei voi olla tyhjä",
    "Replace current password" : "Korvaa nykyinen salasana",
    "Allow upload and editing" : "Salli lähetys ja muokkaus",
    "Allow editing" : "Salli muokkaus",
    "Advanced settings" : "Lisäasetukset",
    "Share label" : "Jaon nimi",
    "Generating…" : "Luodaan…",
    "Set password" : "Aseta salasana",
    "Password expires {passwordExpirationTime}" : "Salasana vanhenee {passwordExpirationTime}",
    "Password expired" : "Salasana vanheni",
    "Video verification" : "Videovarmistus",
    "Expiration date (enforced)" : "Vanhenemispäivä (pakotettu)",
    "Set expiration date" : "Aseta vanhenemispäivä",
    "Hide download" : "Piilota lataus",
    "Note to recipient" : "Huomio vastaanottajalle",
    "Enter a note for the share recipient" : "Lisää muistiinpano jaon vastaanottajalle",
    "Delete share" : "Poista jako",
    "Others with access" : "Muut, joilla on käyttöoikeus",
    "Toggle list of others with access to this directory" : "Vaihda näkymää kansioon käyttöoikeuden omaavista käyttäjistä",
    "Toggle list of others with access to this file" : "Vaihda näkymää tiedostoon käyttöoikeuden omaavista käyttäjistä",
    "Shares" : "Jaot",
    "Unable to load the shares list" : "Jakolistan haku epäonnistui",
    "Expires {relativetime}" : "Vanhenee {relativetime}",
    "this share just expired." : "tämä jako vanheni juuri.",
    "Shared with you by {owner}" : "{owner} jakoi tämän kanssasi",
    "Internal shares" : "Sisäiset jaot",
    "External shares" : "Ulkoiset jaot",
    "Link to a file" : "Linkki tiedostoon",
    "_Accept share_::_Accept shares_" : ["Hyväksy jako","Hyväksy jaot"],
    "Open in Files" : "Avaa tiedostosovelluksessa",
    "_Reject share_::_Reject shares_" : ["Hylkää jako","Hylkää jaot"],
    "_Restore share_::_Restore shares_" : ["Palauta jako","Palauta jaot"],
    "Shared" : "Jaettu",
    "Shared by {ownerDisplayName}" : "Jakanut {ownerDisplayName}",
    "Shared multiple times with different people" : "Jaettu useita kertoja eri ihmisten kanssa",
    "Show sharing options" : "Näytä jakamisen valinnat",
    "Shared with others" : "Jaettu muiden kanssa",
    "Upload files to {foldername}" : "Lähetä tiedostot kansioon {foldername}",
    "Public file share" : "Julkinen tiedostojako",
    "Publicly shared file." : "Tiedosto jaettu julkisesti.",
    "No file" : "Ei tiedostoa",
    "Public share" : "Julkinen jako",
    "No files" : "Ei tiedostoja",
    "Overview of shared files." : "Yleisnäkymä jaetuista tiedostoista.",
    "No shares" : "Ei jakoja",
    "Files and folders you shared or have been shared with you will show up here" : "Tiedostot ja kansiot, jotka olet jakanut tai jotka on jaettu kanssasi, näkyvät täällä",
    "Shared with you" : "Jaettu kanssasi",
    "List of files that are shared with you." : "Luettelo kanssasi jaetuista tiedostoista.",
    "Nothing shared with you yet" : "Kanssasi ei ole vielä jaettu mitään",
    "Files and folders others shared with you will show up here" : "Kanssasi jaetut tiedostot ja kansiot näkyvät täällä",
    "List of files that you shared with others." : "Luettelo muille jakamistasi tiedostoista.",
    "Nothing shared yet" : "Ei mitään jaettua",
    "Files and folders you shared will show up here" : "Tiedostot ja kansiot, jotka olet jakanut, näkyvät täällä",
    "Shared by link" : "Jaettu linkin kautta",
    "List of files that are shared by link." : "Luettelo tiedostoista, jotka on jaettu linkin kautta.",
    "No shared links" : "Ei jaettuja linkkejä",
    "Files and folders you shared by link will show up here" : "Linkin kautta jakamasi tiedostot ja kansiot näkyvät täällä",
    "Deleted shares" : "Poistetut jaot",
    "No deleted shares" : "Ei poistettuja jakoja",
    "Pending shares" : "Odottavat jaot",
    "List of unapproved shares." : "Luettelo hyväksymättömistä jaoista.",
    "No pending shares" : "Ei odottavia jakoja",
    "Shares you have received but not approved will show up here" : "Vastaanottamasi jaot, joita ei ole hyväksytty, näkyvät täällä",
    "Error updating the share: {errorMessage}" : "Virhe päivittäessä jakoa: {errorMessage}",
    "Error updating the share" : "Virhe jakoa päivittäessä",
    "File \"{path}\" has been unshared" : "Tiedoston \"{path}\" jakaminen on lopetettu",
    "Folder \"{path}\" has been unshared" : "Kansion \"{path}\" jakaminen on lopetettu",
    "Share saved" : "Jako tallennettu",
    "Shared by" : "Jakanut",
    "Shared with" : "Jaettu",
    "Password created successfully" : "Salasana luotu onnistuneesti",
    "Shared with you and the group {group} by {owner}" : "Jaettu sinun ja ryhmän {group} kanssa käyttäjältä {owner}",
    "Shared with you and {circle} by {owner}" : "{owner} on jakanut tämän sinun ja piirin {circle} kanssa",
    "Shared with you and the conversation {conversation} by {owner}" : "{owner} on jakanut tämän sinun ja keskustelun {conversation} kanssa",
    "Shared with you in a conversation by {owner}" : "{owner} jakoi tämän kanssasi keskustelussa",
    "Share note" : "Jaa muistiinpano",
    "Show list view" : "Näytä listanäkymä",
    "Show grid view" : "Näytä ruudukkonäkymä",
    "Upload files to %s" : "Lähetä tiedostoja käyttäjälle %s",
    "%s shared a folder with you." : "%s jakoi kansion kanssasi.",
    "Note" : "Huomio",
    "Select or drop files" : "Valitse tai pudota tiedostoja",
    "Uploading files" : "Lähetetään tiedostoja",
    "Uploaded files:" : "Lähetetyt tiedostot:",
    "By uploading files, you agree to the %1$sterms of service%2$s." : "Tiedostoja lähettämällä hyväksyt %1$skäyttöehdot%2$s.",
    "Share not found" : "Jakoa ei löytynyt",
    "Back to %s" : "Takaisin kohtaan %s",
    "Add to your Nextcloud" : "Lisää Nextcloudiisi",
    "Waiting…" : "Odotetaan…",
    "error" : "virhe",
    "finished" : "valmis",
    "This will stop your current uploads." : "Tämä pysäyttää meneillään olevat lähetykset.",
    "Move or copy" : "Siirrä tai kopioi",
    "You can upload into this folder" : "Voit lähettää tiedostoja tähän kansioon",
    "No compatible server found at {remote}" : "Yhteensopivaa palvelinta ei löytynyt osoitteesta {remote}",
    "Invalid server URL" : "Virheellinen palvelimen URL",
    "Failed to add the public link to your Nextcloud" : "Julkisen linkin lisääminen Nextcloudiisi epäonnistui",
    "Files" : "Tiedostot",
    "Download all files" : "Lataa kaikki tiedostot",
    "Search for share recipients" : "Etsi jaon vastaanottajia",
    "No recommendations. Start typing." : "Ei suosituksia. Aloita kirjoittaminen.",
    "Password field can't be empty" : "Salasanakenttä ei voi olla tyhjä",
    "Allow download" : "Salli lataus"
},
"nplurals=2; plural=(n != 1);");
